==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/BudgetSummaryReportRequest.pm <==
package Microsoft::AdCenter::V6::ReportingService::BudgetSummaryReportRequest;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::V6::ReportingService::ReportRequest/;

=head1 NAME

Microsoft::AdCenter::V6::ReportingService::BudgetSummaryReportRequest - Represents "BudgetSummaryReportRequest" in Microsoft AdCenter Reporting Service.

=head1 INHERITANCE

Microsoft::AdCenter::V6::ReportingService::ReportRequest

=cut

sub _type_name {
    return 'BudgetSummaryReportRequest';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v6';
}

our @_attributes = (qw/
    Columns
    Scope
    Time
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    Columns => 'ArrayOfBudgetSummaryReportColumn',
    Scope => 'AccountReportScope',
    Time => 'BudgetSummaryReportTime',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    Columns => 1,
    Scope => 1,
    Time => 1,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

Remark: Inherited methods are not listed.

=head2 new

Creates a new instance

=head2 Columns

Gets/sets Columns (ArrayOfBudgetSummaryReportColumn)

=head2 Scope

Gets/sets Scope (AccountReportScope)

=head2 Time

Gets/sets Time (BudgetSummaryReportTime)

=cut

==> Microsoft-AdCenter-8.00_02.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V6/ReportingService/BudgetSummaryReportRequest.pm <==
package Microsoft::AdCenter::V6::ReportingService::BudgetSummaryReportRequest;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::V6::ReportingService::ReportRequest/;

=head1 NAME

Microsoft::AdCenter::V6::ReportingService::BudgetSummaryReportRequest - Represents "BudgetSummaryReportRequest" in Microsoft AdCenter Reporting Service.

=head1 INHERITANCE

Microsoft::AdCenter::V6::ReportingService::ReportRequest

=cut

sub _type_name {
    return 'BudgetSummaryReportRequest';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v6';
}

our @_attributes = (qw/
    Columns
    Scope
    Time
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    Columns => 'ArrayOfBudgetSummaryReportColumn',
    Scope => 'AccountReportScope',
    Time => 'BudgetSummaryReportTime',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    Columns => 1,
    Scope => 1,
    Time => 1,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

Remark: Inherited methods are not listed.

=head2 new

Creates a new instance

=head2 Columns

Gets/sets Columns (ArrayOfBudgetSummaryReportColumn)

=head2 Scope

Gets/sets Scope (AccountReportScope)

=head2 Time

Gets/sets Time (BudgetSummaryReportTime)

=cut
